// Mask for phone number
function maskPhone(input) {
    let value = input.value.replace(/\D/g, '');
    if (value.length > 11) value = value.slice(0, 11);
    
    if (value.length > 2) {
        value = `(${value.slice(0, 2)}) ${value.slice(2)}`;
    }
    if (value.length > 9) {
        value = `${value.slice(0, 9)}-${value.slice(9)}`;
    }
    
    input.value = value;
}

// Mask for CPF
function maskCPF(input) {
    let value = input.value.replace(/\D/g, '');
    if (value.length > 11) value = value.slice(0, 11);
    
    if (value.length > 3) {
        value = `${value.slice(0, 3)}.${value.slice(3)}`;
    }
    if (value.length > 7) {
        value = `${value.slice(0, 7)}.${value.slice(7)}`;
    }
    if (value.length > 11) {
        value = `${value.slice(0, 11)}-${value.slice(11)}`;
    }
    
    input.value = value;
}

// Update quantity function
function updateQuantity(change) {
    const quantityElement = document.getElementById('quantity');
    let currentQuantity = parseInt(quantityElement.textContent);
    currentQuantity = Math.max(1, currentQuantity + change); // Minimum quantity is 1
    quantityElement.textContent = currentQuantity;
    
    // Update totals
    updateTotals(currentQuantity);
}

// Update totals function
function updateTotals(quantity) {
    const basePrice = 99.90;
    let subtotal = basePrice * quantity;

    // Add selected order bumps
    document.querySelectorAll('.order-bump.selected').forEach(orderBump => {
        const price = parseFloat(orderBump.querySelector('.new-price').textContent.replace('R$', '').replace(',', '.'));
        subtotal += price;
    });

    const total = subtotal;

    // Update the display
    document.querySelectorAll('.cart-total').forEach(element => {
        const amountElement = element.querySelector('span:last-child');
        if (element.querySelector('span:first-child').textContent === 'Subtotal') {
            amountElement.textContent = `R$ ${subtotal.toFixed(2)}`;
        } else if (element.querySelector('span:first-child').textContent === 'Total') {
            amountElement.textContent = `R$ ${total.toFixed(2)}`;
        }
    });

    return total;
}

// Function to get selected items
function getSelectedItems() {
    const items = [];
    
    // Add main plan
    const quantity = parseInt(document.getElementById('quantity').textContent);
    items.push({
        unitPrice: 99.90,
        title: "Plano Verão",
        quantity: quantity,
        tangible: false
    });

    // Add selected order bumps
    document.querySelectorAll('.order-bump.selected').forEach(orderBump => {
        const title = orderBump.querySelector('.order-bump-title').textContent;
        const price = parseFloat(orderBump.querySelector('.new-price').textContent.replace('R$', '').replace(',', '.'));
        
        items.push({
            unitPrice: price,
            title: title,
            quantity: 1,
            tangible: false
        });
    });

    return items;
}

// Add event listeners for input masks
document.addEventListener('DOMContentLoaded', function() {
    const phoneInput = document.getElementById('phone');
    const cpfInput = document.getElementById('cpf');
    
    phoneInput.addEventListener('input', function() {
        maskPhone(this);
    });
    
    cpfInput.addEventListener('input', function() {
        maskCPF(this);
    });
    
    // Form submission
    document.getElementById('checkoutForm').addEventListener('submit', function(e) {
        e.preventDefault();
        
        const formData = {
            name: document.getElementById('fullName').value,
            email: document.getElementById('email').value,
            cpf: document.getElementById('cpf').value.replace(/\D/g, ''),
            phone: document.getElementById('phone').value.replace(/\D/g, '')
        };

        // Validate form data
        if (!formData.name || !formData.email || !formData.cpf || !formData.phone) {
            alert('Por favor, preencha todos os campos obrigatórios.');
            return;
        }

        // Get the current total amount and redirect
        const total = updateTotals(parseInt(document.getElementById('quantity').textContent));
        const userId = '12345'; // This should come from your authentication system
        window.location.href = `/checkout?amount=${total.toFixed(2)}&cpf=${formData.cpf}&email=${formData.email}&phone=${formData.phone}&nome=${formData.name}`;
    });

    // Add click handlers for order bump selection
    document.querySelectorAll('.order-bump-button').forEach(button => {
        button.addEventListener('click', function(e) {
            e.preventDefault();
            const orderBump = this.closest('.order-bump');
            const isSelected = orderBump.classList.contains('selected');
            
            if (!isSelected) {
                orderBump.classList.add('selected');
                this.textContent = 'OFERTA SELECIONADA';
            }
            
            updateTotals(parseInt(document.getElementById('quantity').textContent));
        });
    });

    // Add click handlers for removing order bumps
    document.querySelectorAll('.remove-order-bump').forEach(button => {
        button.addEventListener('click', function(e) {
            e.preventDefault();
            const orderBump = this.closest('.order-bump');
            orderBump.classList.remove('selected');
            orderBump.querySelector('.order-bump-button').textContent = 'PEGAR OFERTA';
            updateTotals(parseInt(document.getElementById('quantity').textContent));
        });
    });
});